euclid_distance: Calculate the Distance between a Point and a Vector

Description Usage Arguments Value

View source: R/colorer.R

Description

Takes a point 'x' and calculates the euclidean distance from a vector 'y'.

Usage

1

Arguments

x

A numerical value.

y

A numerical value or vector.

Value

A vector of distances


jcbain/cuttlefish documentation built on Aug. 5, 2019, 1:49 p.m.