extract_colors: Find Unique RGB Colors in an Image

Description Usage Arguments Value

View source: R/colorer.R

Description

'extract_colors' takes in an image and returns all of the unique colors in the image in RGB color-space.

Usage

1

Arguments

image

The image to load.

Value

Returns a vector of hex colors in the image.


jcbain/cuttlefish documentation built on Aug. 5, 2019, 1:49 p.m.