find_prominent: Create a Palette of the Most Prominent Colors of an Image

Description Usage Arguments Value

View source: R/colorer.R

Description

Creates a color palette from the most prominent 'n' colors of a provided image.

Usage

1
find_prominent(hexes, n)

Arguments

hexes

A vector of hex colors.

n

top 'n' most prominent colors.

Value

Vector of the most prominent hex colors.


jcbain/cuttlefish documentation built on Aug. 5, 2019, 1:49 p.m.