find_segmented: Find the n Most Distinct Colors

Description Usage Arguments Value

View source: R/colorer.R

Description

'find_segmented' selects the most distinct set of colors from a set of colors.

Usage

1
find_segmented(hexes, n, max.distance = TRUE)

Arguments

hexes

A vector of hex colors.

n

'n' distinct colors to be output.

max.distance

Option to make the distance from the saturation and value of color_i from color_i+1 either the farthest ('TRUE') or closest ('FALSE').

Value

Matrix of distinct hsv colors.


jcbain/cuttlefish documentation built on Aug. 5, 2019, 1:49 p.m.