Description Usage Arguments Value
'extract_colors' takes in an image and returns all of the unique colors in the image in RGB color-space.
1 |
image |
The image to load. |
Returns a vector of hex colors in the image.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.