Description Usage Arguments Value
'find_segmented' selects the most distinct set of colors from a set of colors.
1 | find_segmented(hexes, n, max.distance = TRUE)
|
hexes |
A vector of hex colors. |
n |
'n' distinct colors to be output. |
max.distance |
Option to make the distance from the saturation and value of color_i from color_i+1 either the farthest ('TRUE') or closest ('FALSE'). |
Matrix of distinct hsv colors.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.